card_list_shaft: Shaft for ARD list-columns

View source: R/print.R

card_list_shaftR Documentation

Shaft for ARD list-columns

Description

Builds a pillar::pillar_shaft() for a list-column. When every element is a scalar (length-1 atomic) that can be combined to a common type, the column is formatted natively (significant figures, alignment, colour, width shrinking). Otherwise each element is formatted individually: scalars as their value and everything else as the standard tibble summary (⁠<chr [2]>⁠, ⁠<fn>⁠, ⁠<NULL>⁠, ...). NULL elements are always shown as ⁠<NULL>⁠ (rather than coerced to NA).

Usage

card_list_shaft(x, ...)

Arguments

x

(list)
a list-column

...

passed to the underlying pillar shaft constructors

Value

a pillar_shaft object


cards documentation built on Aug. 21, 2026, 5:09 p.m.