flashcard_pdf: flashcards

Description Usage Arguments

View source: R/flashcard_pdf.R

Description

flashcards

Usage

1
2
flashcard_pdf(ggplot_object, pdf_name = "student_cards.pdf",
  front_back = TRUE)

Arguments

ggplot_object

the object that is output from the ggplot_faces function

pdf_name

a character string with the name of the file to be saved. Will be saved to working directory.

front_back

states wether to make the pdf output work for a front back printer or to create two pdfs for a basic printer. Defaults to 'TRUE' for a front and back printer.


hathawayj/cards documentation built on Nov. 4, 2019, 1:29 p.m.