ggplot_faces: @title ggplot faces @param faces This variable uses the...

Description Usage

View source: R/ggplot_faces.R

Description

@title ggplot faces @param faces This variable uses the all_faces object in the list ouput from the jpeg_roll function. @param faces_names This variable uses the all_names object in the list ouput from the jpeg_roll function.

Usage

1
ggplot_faces(faces, faces_names)

hathawayj/cards documentation built on Nov. 4, 2019, 1:29 p.m.