Pictorial Class Roll to by student
1 |
image_files |
the image files that are to be converted |
plot_color |
plot the color shading values for the pixels while data is being digested in the function. Defaults to TRUE |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.