pdf_2image: PDF to image conversion (imagemagick)

Description Usage Arguments

View source: R/pdf_2image.R

Description

PDF to image conversion (imagemagick)

Usage

1
pdf_2image(file = file.choose(), image_type = "jpg", path_out = NULL)

Arguments

magick_path

the full character path to the imagemagick convert command. For example, "C:\Program Files\ImageMagick-6.9.2-Q16\convert.exe" is the default. @param image_type the type of image format to use in the conversion. Will only do one conversion time per function call. Input as character and 'jpg' is the default.

files

the files to be converted. Input as a list of character strings. The working directory will be pre appended to the file names. @examples pdf_2image(files=file.choose())


hathawayj/cards documentation built on Nov. 4, 2019, 1:29 p.m.