View source: R/ard_tabulate_rows.R
| ard_tabulate_rows | R Documentation |
Tabulate the number of rows in a data frame.
ard_tabulate_rows(
data,
colname = "..row_count..",
by = dplyr::group_vars(data),
strata = NULL,
fmt_fun = NULL
)
data |
( |
colname |
( |
by, strata |
(
Arguments may be used in conjunction with one another. |
fmt_fun |
( |
an ARD data frame of class 'card'
ard_tabulate_rows(ADSL, by = TRTA)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.