(tidy-select)
columns to use for grouping or stratifying the table output.
Arguments are similar, but with an important distinction:
by: results are tabulated by all combinations of the columns specified,
including unobserved combinations and unobserved factor levels.
strata: results are tabulated by all observed combinations of the
columns specified.
Arguments may be used in conjunction with one another.