| .message_or_error | R Documentation |
Either error or message depending on input.
.message_or_error(
msg,
error = FALSE,
call = get_cli_abort_call(),
envir = rlang::caller_env()
)
msg |
(scalar |
error |
(scalar |
call |
The execution environment of a currently running
function, e.g. You only need to supply Can also be For more information about error calls, see Including function calls in error messages. |
envir |
( |
Invisible NULL
## Not run:
cards:::.message_or_error("This will be a message", FALSE)
cards:::.message_or_error("This will be an error", TRUE)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.