| .unique_and_sorted | R Documentation |
Essentially a wrapper for unique(x) sorted in the C locale with NA levels
removed. Character values are ordered with order(method = "radix"), so the
result is independent of the session locale and matches the ordering
dplyr::arrange() applies. For factors, all levels are returned even if they
are unobserved. Similarly, logical vectors always return c(TRUE, FALSE),
even if both levels are not observed.
.unique_and_sorted(x, useNA = c("no", "always"))
x |
( |
a vector
cards:::.unique_and_sorted(factor(letters[c(5, 5:1)], levels = letters))
cards:::.unique_and_sorted(c(FALSE, TRUE, TRUE, FALSE))
cards:::.unique_and_sorted(c(5, 5:1))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.