View source: R/flashcard_pdf.R
flashcards
1 2 | flashcard_pdf(ggplot_object, pdf_name = "student_cards.pdf",
front_back = TRUE)
|
ggplot_object |
the object that is output from the ggplot_faces function |
pdf_name |
a character string with the name of the file to be saved. Will be saved to working directory. |
front_back |
states wether to make the pdf output work for a front back printer or to create two pdfs for a basic printer. Defaults to 'TRUE' for a front and back printer. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.