@title ggplot faces @param faces This variable uses the all_faces object in the list ouput from the jpeg_roll function. @param faces_names This variable uses the all_names object in the list ouput from the jpeg_roll function.
1 | ggplot_faces(faces, faces_names)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.