PDF to image conversion (imagemagick)
1 | pdf_2image(file = file.choose(), image_type = "jpg", path_out = NULL)
|
magick_path |
the full character path to the imagemagick convert command. For example, "C:\Program Files\ImageMagick-6.9.2-Q16\convert.exe" is the default. @param image_type the type of image format to use in the conversion. Will only do one conversion time per function call. Input as character and 'jpg' is the default. |
files |
the files to be converted. Input as a list of character strings. The working directory will be pre appended to the file names. @examples pdf_2image(files=file.choose()) |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.