| print.card | R Documentation |
Print method for objects of class 'card'.
## S3 method for class 'card'
print(
x,
width = NULL,
...,
n = NULL,
max_extra_cols = NULL,
max_footer_lines = NULL
)
## S3 method for class 'card'
ctl_new_pillar(controller, x, width, ..., title = NULL)
## S3 method for class 'card'
tbl_format_setup(x, width = NULL, ...)
## S3 method for class 'compare_ard'
print(x, ...)
x |
( |
width |
( |
... |
( |
n |
( |
max_extra_cols, max_footer_lines |
( |
controller, title |
arguments passed by the pillar print machinery; not called directly |
ARD tibbles print like a typical tibble (via the pillar package) with a few ARD-specific adaptations:
the header reads An ARD data frame instead of A tibble
list-columns whose elements are scalars print the value of the element,
falling back to the standard tibble summary (e.g. <chr [2]>, <fn>) for
non-scalar elements
when the tibble is too wide for the console, all-NULL error and
warning columns are suppressed first, then (after the usual column
shrinking) the fmt_fun, stat_label, stat_fmt, and context columns
are dropped in that order before falling back to the standard tibble
behaviour. Suppressed columns are reported in the footer.
an ARD data frame of class 'card' (invisibly)
ard_tabulate(ADSL, variables = AGEGR1) |>
print()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.