This function is used to sort stacked hierarchical ARDs.
For the purposes of this function, we define a "variable group" as a combination of ARD rows grouped by the
combination of all their variable levels, but excluding any by variables.
sort_ard_hierarchical(x, sort = everything() ~ "descending", by_level = NULL)an ARD data frame of class 'card'
(card)
a stacked hierarchical ARD of class 'card' created using ard_stack_hierarchical() or
ard_stack_hierarchical_count().
(formula-list-selector, string)
a named list, a list of formulas, a single formula where the list element is a named list of functions
(or the RHS of a formula), or a single string specifying the types of sorting to perform at each hierarchy variable
level. If the sort method for any variable is not specified then the method will default to "descending". If a
single unnamed string is supplied it is applied to all variables. For each variable, the value specified must
be one of:
"alphanumeric" - at the specified hierarchy level of the ARD, groups are ordered alphanumerically
(i.e. A to Z) by variable_level text.
"descending" - within each variable group of the ARD at the specified hierarchy level, count sums are
calculated for each group and groups are sorted in descending order by sum. When sort is "descending" for a
given variable and n is included in statistic for the variable then n is used to calculate variable group
sums, otherwise p is used. If neither n nor p are present in x for the variable, an error will occur.
Defaults to everything() ~ "descending".
(named list)
a named list used to restrict the counts used for "descending" sorting to one or more specific by variable
levels. Each name must be one of the by variables used to create x, and each element must be a single level of
that by variable. When supplied, "descending" sorts rank variable groups by the count sums calculated only from
the rows matching every specified by variable level (e.g. list(TRTA = "Placebo") sorts by the counts observed
in the "Placebo" arm), rather than the sums across all by variable levels. Any by variable not named in the
list is not restricted. This argument has no effect on variables sorted "alphanumeric".
Defaults to NULL, in which case count sums are calculated across all by variable levels.
filter_ard_hierarchical()